import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface NfsStorageClassConfig extends cdktf.TerraformMetaArguments {
    /**
    * The content types that can be stored on this storage class.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/proxmox/r/nfs_storage_class#content_types NfsStorageClass#content_types}
    */
    readonly contentTypes?: string[];
    /**
    * The remote export path of the NFS server.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/proxmox/r/nfs_storage_class#export NfsStorageClass#export}
    */
    readonly export: string;
    /**
    * The identifier of the storage class.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/proxmox/r/nfs_storage_class#id NfsStorageClass#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * Nodes that implement this storage class.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/proxmox/r/nfs_storage_class#nodes NfsStorageClass#nodes}
    */
    readonly nodes?: string[];
    /**
    * The NFS server used in the storage class.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/proxmox/r/nfs_storage_class#server NfsStorageClass#server}
    */
    readonly server: string;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/proxmox/r/nfs_storage_class proxmox_nfs_storage_class}
*/
export declare class NfsStorageClass extends cdktf.TerraformResource {
    static readonly tfResourceType = "proxmox_nfs_storage_class";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/proxmox/r/nfs_storage_class proxmox_nfs_storage_class} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options NfsStorageClassConfig
    */
    constructor(scope: Construct, id: string, config: NfsStorageClassConfig);
    private _contentTypes?;
    get contentTypes(): string[];
    set contentTypes(value: string[]);
    resetContentTypes(): void;
    get contentTypesInput(): string[] | undefined;
    private _export?;
    get export(): string;
    set export(value: string);
    get exportInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    get mount(): string;
    private _nodes?;
    get nodes(): string[];
    set nodes(value: string[]);
    resetNodes(): void;
    get nodesInput(): string[] | undefined;
    private _server?;
    get server(): string;
    set server(value: string);
    get serverInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
