import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ResourcePoolConfig extends cdktf.TerraformMetaArguments {
    /**
    * Notes on the resource pool.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/proxmox/r/resource_pool#comment ResourcePool#comment}
    */
    readonly comment?: string;
    /**
    * The id of the resource pool.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/proxmox/r/resource_pool#id ResourcePool#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * Resources that are part of the resource pool.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/proxmox/r/resource_pool#members ResourcePool#members}
    */
    readonly members?: ResourcePoolMembers[] | cdktf.IResolvable;
}
export interface ResourcePoolMembers {
    /**
    * The id of the resource.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/proxmox/r/resource_pool#id ResourcePool#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * The type of the resource.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/proxmox/r/resource_pool#type ResourcePool#type}
    */
    readonly type: string;
}
export declare function resourcePoolMembersToTerraform(struct?: ResourcePoolMembers | cdktf.IResolvable): any;
export declare class ResourcePoolMembersOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ResourcePoolMembers | cdktf.IResolvable | undefined;
    set internalValue(value: ResourcePoolMembers | cdktf.IResolvable | undefined);
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    get typeInput(): string | undefined;
}
export declare class ResourcePoolMembersList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ResourcePoolMembers[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ResourcePoolMembersOutputReference;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/proxmox/r/resource_pool proxmox_resource_pool}
*/
export declare class ResourcePool extends cdktf.TerraformResource {
    static readonly tfResourceType = "proxmox_resource_pool";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/proxmox/r/resource_pool proxmox_resource_pool} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options ResourcePoolConfig
    */
    constructor(scope: Construct, id: string, config: ResourcePoolConfig);
    private _comment?;
    get comment(): string;
    set comment(value: string);
    resetComment(): void;
    get commentInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _members;
    get members(): ResourcePoolMembersList;
    putMembers(value: ResourcePoolMembers[] | cdktf.IResolvable): void;
    resetMembers(): void;
    get membersInput(): cdktf.IResolvable | ResourcePoolMembers[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
