import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ZfsStorageClassConfig extends cdktf.TerraformMetaArguments {
    /**
    * The content types that can be stored on this storage class.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/proxmox/r/zfs_storage_class#content_types ZfsStorageClass#content_types}
    */
    readonly contentTypes?: string[];
    /**
    * The id of the ZFS storage class.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/proxmox/r/zfs_storage_class#id ZfsStorageClass#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * Nodes that implement this storage class.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/proxmox/r/zfs_storage_class#nodes ZfsStorageClass#nodes}
    */
    readonly nodes?: string[];
    /**
    * The ZFS pool of the storage.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/proxmox/r/zfs_storage_class#pool ZfsStorageClass#pool}
    */
    readonly pool: string;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/proxmox/r/zfs_storage_class proxmox_zfs_storage_class}
*/
export declare class ZfsStorageClass extends cdktf.TerraformResource {
    static readonly tfResourceType = "proxmox_zfs_storage_class";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/proxmox/r/zfs_storage_class proxmox_zfs_storage_class} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options ZfsStorageClassConfig
    */
    constructor(scope: Construct, id: string, config: ZfsStorageClassConfig);
    private _contentTypes?;
    get contentTypes(): string[];
    set contentTypes(value: string[]);
    resetContentTypes(): void;
    get contentTypesInput(): string[] | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    get mount(): string;
    private _nodes?;
    get nodes(): string[];
    set nodes(value: string[]);
    resetNodes(): void;
    get nodesInput(): string[] | undefined;
    private _pool?;
    get pool(): string;
    set pool(value: string);
    get poolInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
